//
// Created by maomao on 2023/9/19.
//

#include "png-extractortest.h"
#include "extractors/png-extractor.h"
#include "simple-extraction-result.h"
#include "indexerextractortestsconfig.h"
#include "mime-utils.h"
#include <QTest>

using namespace UkuiFileMetadata;

void PngExtractorTest::testNoExtraction() {
    PngExtractor plugin{this};
    QDir dir(QStringLiteral(INDEXER_TESTS_SAMPLE_FILES_PATH) + QStringLiteral("/pngTest"));
    for (const QString &fileName : dir.entryList(QDir::NoDotAndDotDot | QDir::Files)) {
        QString filePath = dir.path() + "/" + fileName;
        QMimeDatabase mimeDb;
        QString mimeType = MimeUtils::strictMimeType(filePath, mimeDb).name();
        SimpleExtractionResult result(filePath, mimeType, ExtractionResult::ExtractNothing);
        plugin.extract(&result);

        QCOMPARE(result.types().size(), 1);
        QCOMPARE(result.types().constFirst(), Type::Image);
        QCOMPARE(result.properties().size(), 0);
    }
}

void PngExtractorTest::testMetaDataOnly() {
    PngExtractor plugin{this};
    QDir dir(QStringLiteral(INDEXER_TESTS_SAMPLE_FILES_PATH) + QStringLiteral("/pngTest"));
    for (const QString &fileName : dir.entryList(QDir::NoDotAndDotDot | QDir::Files)) {
        QString filePath = dir.path() + "/" + fileName;
        QMimeDatabase mimeDb;
        QString mimeType = MimeUtils::strictMimeType(filePath, mimeDb).name();
        SimpleExtractionResult result(filePath, mimeType, ExtractionResult::ExtractMetaData);
        plugin.extract(&result);

        QCOMPARE(result.properties().value(Property::Author), QVariant("Author"));
        QCOMPARE(result.properties().value(Property::Title), QVariant("Title"));
        QCOMPARE(result.properties().value(Property::Copyright), QVariant("Copyright"));
        QCOMPARE(result.properties().value(Property::Generator), QVariant("Generator"));
        QCOMPARE(result.properties().value(Property::Comment), QVariant("Comment"));
    }
}

void PngExtractorTest::testPngContent() {
    PngExtractor plugin{this};
    QDir dir(QStringLiteral(INDEXER_TESTS_SAMPLE_FILES_PATH) + QStringLiteral("/pngTest"));
    for (const QString &fileName : dir.entryList(QDir::NoDotAndDotDot | QDir::Files)) {
        QString filePath = dir.path() + "/" + fileName;
        QMimeDatabase mimeDb;
        QString mimeType = MimeUtils::strictMimeType(filePath, mimeDb).name();
        SimpleExtractionResult result(filePath, mimeType, ExtractionResult::ExtractPlainText);
        qDebug() << QDateTime::currentDateTime().toString();
        plugin.extract(&result);
        qDebug() << QDateTime::currentDateTime().toString() << "======filePath" << filePath << result.text();
    }
}

QTEST_GUILESS_MAIN(PngExtractorTest)